import logging

config = {

    "settings": {

        # To be used by Flask: DEVELOPMENT ONLY
        "debug": True,

        # Flask host: DEVELOPMENT ONLY
        "host": "localhost",

        # Flask port: DEVELOPMENT ONLY
        "port": 5975,

        # metadata config
        "metadata": {
            "url_create_metadata": "//exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources/metadata",
            "url_get_metadata_uid": "//exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources/metadata/uid/<uid>",
            # get metadata
            "url_get_metadata": "//exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources/metadata/uid/<uid>",
            "url_get_full_metadata": "//exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources/metadata/uid/<uid>?full=true&dsd=true",
            # coding system
            "url_create_coding_system": "//exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources",
            "url_data_coding_system": "://exldvsdmxreg1.ext.fao.org:7788/v2/msd/resources/data/uid/<uid>",
        }
    }
}
